@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## PO Files Manipulation - ~/lib/Text/PO/Gettext.pm
-## Version v0.1.1
+## Version v0.1.2
 ## Copyright(c) 2021 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/07/12
-## Modified 2021/07/30
+## Modified 2021/08/09
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -35,7 +35,7 @@ BEGIN
             (?:\.(?<locale_encoding>[\w-]+))?
         )
     $/x;
-    our $VERSION = 'v0.1.1';
+    our $VERSION = 'v0.1.2';
 };
 
 sub init
@@ -410,6 +410,8 @@ sub gettext
     return( $self->dngettext( $self->domain, shift( @_ ) ) );
 }
 
+sub gettextf { return( shift->getTextf( @_ ) ); }
+
 sub isSupportedLanguage
 {
     my $self = shift( @_ );
@@ -684,7 +686,7 @@ Text::PO::Gettext - A GNU Gettext implementation
 
     use Text::PO::Gettext;
     my $po = Text::PO::Gettext->new || die( Text::PO::Gettext->error, "\n" );
-    my $po = new Gettext({
+    my $po = Text::PO::GettextGettext->new({
         category => 'LC_MESSAGES',
         debug    => 3,
         domain   => "com.example.api",
@@ -695,7 +697,7 @@ Text::PO::Gettext - A GNU Gettext implementation
 
 =head1 VERSION
 
-    v0.1.1
+    v0.1.2
 
 =head1 DESCRIPTION
 
@@ -1168,6 +1170,10 @@ Provided with a C<msgid> represented by a string, and this return a localised ve
 
 See the global function L</_> for more information.
 
+=head2 gettextf
+
+This is an alias to L</getTextf>
+
 =head2 isSupportedLanguage
 
 Provided with a locale such as C<fr-FR> or C<ja_JP> no matter whether an underscore or a dash is used, and this will return true if the locale has already been loaded and thus is supported. False otherwise.
